.. image:: images/logo.png

-------------------------------------

Glossary
===================

.. Glossary::
    :sorted:

    Survival analysis
        Statistical technique to correct for left, right and interval censoring

    Interpretational voids
        Internal areas of the boundaries in which it is impossible to carry out fracture interpretation

    Interpretational boundaries
        Areas in which it is possible to carry out fracture interpretation

    Topology
        Topology studies the set of properties of an object (components) that are
        preserved through deformation without tearing or ripping (Mallet 2002) and describes
        the way different parts of an object are connected.

    Digital Outcrop Models (DOMs)
        Qualitative three-dimensional representations of suitable rock outcrops
